@@ -13,6 +13,7 @@ import tempfile
 from pathlib import Path
 from types import SimpleNamespace
 import zipfile
+from shutil import which
 from pathlib import Path
 
 from . import common
@@ -120,13 +121,13 @@ class WheelBuilder:
         make_path = directory / maker.get("makefile", "Makefile")
         build_system = get_build_system(xmake_path, make_path, configure_path, configure_ac_path)
         if build_system == "xmake":
-            xmake = XMaker(xmaker.get("xmake", "xmake"),
+            xmake = XMaker(xmaker.get("xmake", which("xmake")),
                            xmaker.get("command", ""),
                            xmaker.get("tempname", ""),
                            xmaker.get("project", os.path.abspath(".")),
                            ini_info.metadata["version"])
         elif build_system in ["make", "autotools"]:
-            xmake = Maker(maker.get("make", "make"),
+            xmake = Maker(maker.get("make", which("make")),
                            maker.get("command", ""),
                            maker.get("tempname", ""),
                            maker.get("project", os.path.abspath(".")),
@@ -287,6 +288,8 @@ class WheelBuilder:
         # Write a record of the files in the wheel
         with self._write_to_zip(self.dist_info + '/RECORD') as f:
             for path, hash, size in self.records:
+                if path.find(',') >= 0:
+                    path = f'"{path}"'
                 f.write('{},sha256={},{}\n'.format(path, hash, size))
             # RECORD itself is recorded with no hash or size
             f.write(self.dist_info + '/RECORD,,\n')
